# x86 backend integration test

In addition to the FileCheck test, we provide a harness here to verify that
the x86 assembly code generated by xDSL can be assembled and linked, and
computes a correct matrix multiplication.

+ To check assembly: `make matmul.o` in this directory
+ To check linking: `make exe`
+ To verify the computation: `make check` (assuming that the host machine is
x86-64 and allows AVX2)
